" Script Nmame: code toolkit
" File Name:    ctk.vim
" Author:       StarWing
" Version:      0.3
" Last Change:  2009-05-09 23:12:57
" Note:         see :ctk for details
" ==========================================================
" load once {{{1

if v:version < 700
    echomsg "ctk.vim requires Vim 7.0 or above."
    finish
endif

let s:cpo_save = &cpo
set cpo&vim

scriptencoding utf-8
if !exists('g:loaded_ctk')
    let g:loaded_ctk = 'v0.3'

    " options {{{2
    function! s:defopt(opt, val)
	if !exists(a:opt) | let {a:opt} = a:val | endif
    endfunction

    call s:defopt('g:ctk_autofname', 'strftime("%Y-%m-%d")."-".idx')
    call s:defopt('g:ctk_cinfo_file', '.compiler_info')
    call s:defopt('g:ctk_defoutput', './output')
    call s:defopt('g:ctk_ext_var', 'ft_ext')
    call s:defopt('g:ctk_tempdir', './noname')

    if has('win32')
        call s:defopt('g:ctk_execprg', executable('vimrun') ?
                    \ 'start vimrun $exec' : 'start $exec')
    elseif has('unix') && has('gui_running')
        call s:defopt('g:ctk_execprg', 'xterm -e "$exec; '.
                    \ 'echo \"$exec returned $?\";read -s -n1 '.
                    \ '-p\"press any key to continue...\"" &')
    else
        call s:defopt('g:ctk_execprg', '')
    endif

    delfunc s:defopt

    " commands {{{2
    command! -bar StartCTK call s:start_ctk()
    command! -bar StopCTK call s:stop_ctk()
    command! -bar EditCompilerInfo exec 'drop '.globpath(&rtp, g:ctk_cinfo_file)

    command! -nargs=* -complete=customlist,s:info_name_complete -bar -count=0 
	    \ ListCompiler call s:ctk_call('s:list_compiler', [<q-args>, <count>])
    command! -nargs=* -complete=custom,s:info_item_complete -bang
	    \ SetCompilerInfo call Set_compiler_info(<q-args>, '<bang>')
    command! -nargs=+ -complete=custom,s:info_item_complete
            \ SetDefaultInfo call Set_default_info(<q-args>)
    command! -nargs=+ -complete=custom,s:info_item_complete -count=0
	    \ AddFlags call s:ctk_call('s:add_flags', [<q-args>, <count>])

    command! -nargs=? -bar -bang -count=0 CC call s:ctk_call('s:compile',
                \ [<count>, <q-args>, <q-bang>])
    command! -nargs=? -bar -bang -count=0 RUN call s:ctk_call('s:run',
                \ [<count>, <q-args>, <q-bang>])

    map <silent> <Plug>CTK_compile :<C-U>exec v:count.'CC'<CR>
    imap <silent> <Plug>CTK_compile <ESC>:<C-U>exec v:count.'CC'<CR>
    map <silent> <Plug>CTK_run :<C-U>exec v:count.'RUN'<CR>
    imap <silent> <Plug>CTK_run <ESC>:<C-U>exec v:count.'RUN'<CR>

    " menus {{{2

    amenu &Tools.&CTK.&Start :StartCTK<CR>
    amenu &Tools.&CTK.&Stop  :StopCTK<CR>
    amenu &Tools.&CTK.-Sep- :
    amenu <silent> &Tools.&CTK.&Add\ a\ modeline :exec 'AddFlags '.(has('gui_running') ? inputdialog("Please input the text in modeline:", "flags += ''") : input("Modeline:", "flags += ''"))<CR>
    amenu &Tools.&CTK.&List\ All\ Compiler :ListCompiler all<CR>
    amenu &Tools.&CTK.&Compile :CC<CR>
    amenu &Tools.&CTK.&Run :RUN<CR>

    " small functions {{{2
    let s:sfile = expand('<sfile>')

    function! s:start_ctk() " {{{3
        augroup ctk_autocmds
            au!

            " 1 means this name is user-modifiled
            au BufFilePost * let b:ctk_fname = [expand('%:p'), &ft, 1]

            au FileType * call s:delete_ci()
            exec 'run '.g:ctk_cinfo_file
            au FileType * call s:set_fname()

            au FuncUndefined Set_compiler_info,Set_default_info
                        \ exec 'so '.s:sfile
        augroup END
        map gc <Plug>CTK_compile
        map gC <Plug>CTK_run
    endfunction
    function! s:stop_ctk() " {{{3
        call s:delete_ci()
        unlet! b:ctk_fname b:{ctk_ext_var}
        au! ctk_autocmd
        unmap gc
        unmap gC
    endfunction
    function! s:ctk_call(funcname, args) " {{{3
        if exists('b:compiler_info')
            call call(a:funcname, a:args)
        else
            echohl Error
            echom "command can't use, because ctk isn't avaliable"
            echohl None
        endif
    endfunction
    function! s:need_update() " {{{3
        return !exists('b:ctk_fname') || b:ctk_fname[1] != &ft
    endfunction
    function! s:delete_ci() " {{{3
        if s:need_update()
            unlet! b:{g:ctk_ext_var}
            if exists('b:compiler_info')
                for info in get(b:compiler_info, 'list', [])
                    silent! exec info.unmap
                endfor
                unlet b:compiler_info
            endif
        endif
    endfunction
    function! s:set_fname() " {{{3
        if g:ctk_autofname == ''
            return
        endif

        if exists('b:ctk_fname')
            " if the name is autocreated and now we don't have a filetype,
            " delete the name
            if !b:ctk_fname[2] && &ft == ''
                silent! noau 0file | unlet b:ctk_fname

            " if we have a filename and it isn't same as ctk_fname, set it to
            " user-defined (that is, the name is chnanged by user)
            elseif b:ctk_fname[0] != expand('%:p') || b:ctk_fname[2]
                let b:ctk_fname = [expand('%:p'), &ft, 1]

            " otherwise, call set_filename to set autocreated name
            elseif &ft !=? 'decho' && b:ctk_fname[1] != &ft
                call s:set_filename()
            endif
            return
        endif

        " if we really have a filetype and this type isn't our debug window's
        " and we don't have a filename, and we have a compiler info, set auto
        " name.
        if &ft != '' && &ft !=? 'decho' && expand('%') == ''
                    \ && exists('b:compiler_info')
            call s:set_filename()
        else
            let b:ctk_fname = [expand('%:p'), &ft, 1]
        endif
    endfunction
function! s:info_name_complete(A, L, P) " {{{3
    if !exists(s:ci_name) | return [] | endif
    let list = []
    for dict in b:{s:ci}.list
        let list += [dict.name]
    endfor
    let pat = "'^\\v".substitute(escape(a:A, '\'), "'", "''", 'g')."'"
    return sort(filter(list + ['all', 'default', 'current'],
                \ 'v:val =~ '.pat))
endfunction
function! s:info_item_complete(A, L, P) " {{{3
    return "asm_\ncc\ncmd\ndebug_\nflags\n".
                \ "input\noutput\nrun\ntitle"
endfunction " }}}3

    StartCTK
    " }}}2

    finish
endif

" }}}1
" core functions {{{1

" some inner variables {{{2

" escape chars in filename {{{3
let s:fname_escape_chars = " \t\n*?[{`$\\%#'\"|!<"

" buffer-variable names {{{3
let s:ci = 'compiler_info'
let s:ci_name = 'b:'.s:ci

" some default attr {{{3
let s:def_attr = {'cmd': ':echo "Done Nothing"', 'run': ':echo "Done Nothing"',
            \ 'input': '%:.', 'output': '%:t:r'}

" patterns {{{3

let s:pat_cmdtag = '$\(\l\+\)'
let s:pat_cmdtag_quote = '${q-\(\l\+\)}'
let s:pat_com = ':\zs[^,]\+'
let s:pat_com_begin = 's.\=:\zs[^,]\+\ze'
let s:pat_com_end = 'e.\=:\zs[^,]\+\ze'
let s:pat_execoutput = '\%^[\r\n]*\zs.\{-}\ze[\r\n]*\%$'
let s:pat_exectag = '$exec\>'
let s:pat_filespec = '\v%(\%|#%(\d+)=|##|<cword>|<cWORD>)%(:[p8~.htre]|g=s(.).\{-}\1.\{-}\1)*'
let s:pat_filespec_escape = '\\\ze'.s:pat_filespec
let s:pat_filespec_nonescape = '\\\@<!'.s:pat_filespec
let s:pat_fname_escape = "[ \t\n*?[{`$\\%#''\"|!<]"
let s:pat_info ='\v^\s*(.{-})%(\s+(.{-})\s*)=$' 
let s:pat_info_var = '\v(\w+)\s*(\+)=\=\s*(\S)(.{-})\3'
let s:pat_modeline = '\v<cc%(-([^:]*))=:\s*(.*)'
let s:pat_shellcmdtitle = '^!\=\zs.\{-}\ze\(\s\|$\)'

" }}}3

" ============================================================
" utility functions {{{2

" tricks to get command-style arglist {{{3
command! -nargs=* CTKGetEscapedList let l:args = [<f-args>]
function! s:get_escaped_list(str)
    exec 'CTKGetEscapedList '.a:str
    return args
endfunction

function! s:question(msg) " {{{3
    redraw
    echohl Question
    echo a:msg
    echohl NONE
    call inputsave()
    let ch = nr2char(getchar())
    call inputrestore()
    return ch
endfunction

function! s:echoerr(msg) " {{{3
    echohl ErrorMsg
    echomsg 's: '.a:msg
    echohl NONE
endfunction

function! s:get_idx(info) " {{{3
    let idx = 0
    for info in b:{s:ci}.list
        if info is a:info
            return idx
        endif
        let idx += 1
    endfor
    return -1
endfunction

function! s:get_entry_val(entry, key, default) " {{{3
    let key = (a:entry == '' ? a:key : a:entry.'_'.a:key)

    if has_key(b:{s:ci}, 'default')
        return get(b:{s:ci}.cur_info, key,
                    \ get(b:{s:ci}.default, key, a:entry == '' ?
                    \ get(s:def_attr, key, a:default) :
                    \ get(b:{s:ci}.cur_info, a:key,
                    \ get(b:{s:ci}.default, a:key,
                    \ get(s:def_attr, a:key, a:default)))))

    else
        return get(b:{s:ci}.cur_info, key, a:entry == '' ?
                    \ get(s:def_attr, a:key, a:default) :
                    \ get(b:{s:ci}.cur_info, a:key,
                    \ get(s:def_attr, a:key, a:default)))
    endif
endfunction

function! s:get_info(name) " {{{3
"    call Dfunc('s:get_info(name = '.a:name.')')
"    call Decho('info_list = '.string(b:{s:ci}.list))
    for info in b:{s:ci}.list
        if info.name ==? a:name
"            call Dret('s:get_info : '.string(info))
            return info
        endif
    endfor
"    call Dret('s:get_info : {}')
    return {}
endfunction

function! s:sub_info(info) " {{{3
"    call Decho('let '.get(a:info, 'name', 'cur_info').'['.submatch(1).'] '.
                \ submatch(2).'= "'.submatch(4).'"')

    let val = submatch(2) == '+' ? s:get_entry_val('', submatch(1), '') : ''
    let val = val == '' ? '' : val.' '
    let a:info[submatch(1)] = val.submatch(4)
endfunction

function! s:expand_fname(fname, mode) " {{{3
"    call Dfunc('s:expand_fname(fname = '.a:fname.', mode = '.a:mode.')')
    let fname = expand(a:fname)

    if a:mode == ':'
        let fname = exists('*fnameescape') ? fnameescape(fname)
                    \ : escape(fname, s:fname_escape_chars)
    endif

    if fname =~ s:pat_fname_escape
        let fname = shellescape(fname)
    endif

"    call Dret('s:expand_fname : '.fname)
    return fname
endfunction " }}}3

" ============================================================
function! Set_compiler_info(cmdarg, bang) " {{{2
    if !s:need_update() | return | endif
"    call Dfunc('s:set_compiler_info(cmdarg = "'.a:cmdarg.'")')
    if !exists(s:ci_name)
        let b:{s:ci} = {'list':[]}
    elseif !has_key(b:{s:ci}, 'list')
        let b:{s:ci}.list = []
    endif

    " empty command
    if a:cmdarg == ''
        if a:bang == '!' | call s:delete_ci() | endif
"        return Dret('s:set_compiler_info')
    endif

    " find name and others, mlist = [all, name, infos]
    let mlist = matchlist(a:cmdarg, s:pat_info)

    " add or modify a info
    if mlist[2] != ''
        let info = s:get_info(mlist[1])

        " add a new info, or clean old info
        " if exists ci.default, use it for default values
        if empty(info)
"            call Decho('add a new info')
            let info.name = mlist[1]
            call add(b:{s:ci}.list, info)
        else
"            call Decho('clear old info: '.string(info))
            silent! exec info.unmap
            call filter(info, 0)
        endif

        let info.name = mlist[1]
        call substitute(mlist[2], s:pat_info_var, '\=s:sub_info(info)', 'g')

        let info.unmap = ''
        let idx = s:get_idx(info)
        let dict = {'cmdmap': 'CC', 'runmap': 'RUN'}
        for key in keys(dict)
            if !has_key(info, key) | continue | endif
            let {key} = ''
"            call Decho('setup '.key)
            for mkey in s:get_escaped_list(info[key])
                let cpos = stridx(mkey, ':')
                for mode in split(cpos <= 0 ? 'nvi' : mkey[:cpos - 1], '\zs')
                    try | exec mode.'noremap <silent><unique> '.mkey[cpos+1:].
                                \ ' <C-\><C-N>:'.(idx+1).dict[key].'!<CR><C-\><C-G>'
                        let info.unmap .= mode.'unmap '.mkey[cpos+1:].'|'
                        let {key} .= mode.'map:'.mkey[cpos+1:].' '
                    catch | endtry
                endfor
            endfor
            if {key} == '' | unlet info[key]
            else | let info[key] = {key} | endif
        endfor

    " remove a info
    elseif a:bang == '!'
        let info = s:get_info(mlist[1])

        if !empty(info)
            silent! exec info.unmap
            call remove(b:{s:ci}, s:get_idx(info))
        endif

    " list a info
    else
        call s:list_compiler(mlist[1])
    endif

"    call Decho('>> now info = '.string(info))
"    call Dret('s:set_compiler_info')
endfunction

function! Set_default_info(cmdarg) " {{{2
    if !s:need_update() | return | endif
"    call Dfunc('s:set_default_info(cmdarg = "'.a:cmdarg.'")')
    let def_info = {}
    if !exists(s:ci_name)
        let b:{s:ci} = {}
    endif
    let b:{s:ci}.default = def_info

    call substitute(a:cmdarg, s:pat_info_var, '\=s:sub_info(def_info)', 'g')

    if has_key(def_info, g:ctk_ext_var)
        let b:{g:ctk_ext_var} = def_info[g:ctk_ext_var]
        unlet def_info[g:ctk_ext_var]
    endif

"    call Dret('s:set_default_info')
endfunction

function! s:compile(count, entry, bang) " {{{2
    " find source buffer, and save it. if failed (return nonzero), echo
    " message and return 1 (failed, no use in this version)
    if !s:find_source() || !s:save_source() ||
                \ a:count < 0 || a:count > len(b:{s:ci}.list)
        redraw | echo 'Nothing Done'
        return 1
    endif
"    call Dfunc('s:compile(count = '.a:count.', entry = '.a:entry.
                \ ', bang = '.a:bang.')')

    " init variables, and make "cur_info" dict.
    let ci = b:{s:ci}
    if a:bang | silent! unlet ci.cur_idx ci.cur_entry | endif
    let ci.cur_idx = a:count == 0 ? get(ci, 'cur_idx', 0) : a:count - 1
    let ci.cur_entry = a:entry == '' ? get(ci, 'cur_entry', '') : a:entry
    call s:make_cur_info(ci.list[ci.cur_idx])

    " "entry" is just something like trigger. you press :CC entry, then
    " "entry" specified commands will be executed.
    redraw | echo 'Compiling ...'
    let ret_val = 1
    let msg = 'Compiling... using '.
                \ s:get_entry_val(ci.cur_entry, 'title', ci.cur_info.name)
    let cmd = s:get_entry_val(ci.cur_entry, 'cmd', '')
    let cmd = s:make_cmd(cmd, ci.cur_entry)
    let res = s:exec_cmd(cmd)
    let cfile = [msg, cmd, ''] + split(res, "\<NL>")

    redraw
    if cmd[0] != ':'
"        call Decho('A shell command')
        let ret_val = v:shell_error
        let cfile += [ci.cur_info.name.' returned '.ret_val]

        try
            call writefile(cfile, &errorfile) 
            cgetfile | exec v:shell_error == 0 ? 'cwindow' : 
                        \ (res == '' ? 'cclose' : 'copen')

            echo 'Compile' (v:shell_error ? 'Fail' : 'Successd')
        catch
            call s:echoerr('error when write error log: '.v:exception)
        endtry

    elseif res != ''
"        call Decho('A exec command')
        echo join(cfile, "\n")
    endif

"    call Dret('s:compile : '.ret_val)
    return ret_val
endfunction

function! s:run(count, entry, bang) " {{{2
    if !s:find_source() | return | endif
    let bufnr = bufnr('%')
    if (a:bang || &modified || !has_key(b:{s:ci}, 'cur_info')
                \ || b:{s:ci}.cur_idx != (a:count - 1)
                \ ) && s:compile(a:count, a:entry, a:bang)
        return 1
    endif
"    call Dfunc('s:run(count = '.a:count.', entry = '.a:entry.
                \ ', bang = '.a:bang.')')

    exec bufwinnr(bufnr).'wincmd w'

    let cmd = s:make_cmd(s:get_entry_val(a:entry, 'run', ''), a:entry)
    if cmd[0] != ':'
        let cmd = cmd[0] == '!' ? cmd[1:] : cmd
        if g:ctk_execprg != ''
            let cmd = substitute(g:ctk_execprg, s:pat_exectag,
                        \ escape(cmd, '\'), 'g')
        endif
        let cmd = (has('gui_running') ? ':silent !' : ':!').cmd
    endif

    let res = s:exec_cmd(cmd)

    if res !~ '^\_s*$'
        redraw
        for line in split(res, '\n\|\r\|\r\n')
            echomsg line
        endfor
        redraw!
    endif

"    call Dret('s:run')
endfunction

function! s:add_flags(flags, count) " {{{2
    if !s:find_source() | return | endif

    if a:count > 0 && a:count <= len(b:{s:ci}.list)
        let compiler = '-'.b:ctk.info[a:count - 1].name
    else
        let compiler = ''
    endif

    let com_begin = matchstr(&com, s:pat_com_begin)
    if com_begin != ''
        let com_begin .= ' '
        let com_end = ' '.matchstr(&com, s:pat_com_end)
    else
        let com_begin = matchstr(&com, s:pat_com).' '
        let com_end = ''
    endif
    
    call append(line('$'), com_begin.'cc'.compiler.': '.a:flags.com_end)
endfunction

function! s:set_filename() " {{{2
"    call Dfunc('s:set_filename()')

    if exists('b:'.g:ctk_ext_var) | let ext = b:{g:ctk_ext_var}
    elseif &sua != '' | let ext = &sua[1:]
    elseif &ft != '' | let ext = &ft
    else | return
    endif

"    call Decho('ext = "'.ext.'"')
    let tempdir = get(b:, 'ctk_tempdir', g:ctk_tempdir)
    if !isdirectory(tempdir) && exists('*mkdir')
        call mkdir(tempdir, 'p')
    endif
    if !isdirectory(tempdir)
        let tempdir = '.'
    endif
    let tempdir = fnamemodify(tempdir, ':p')
"    call Decho('tempdir = "'.tempdir.'"')

    if exists('b:ctk_tempdir')
        let b:ctk_tempdir = tempdir
    else
        let g:ctk_tempdir = tempdir
    endif

    let fname = get(b:, 'ctk_autofname', g:ctk_autofname)
    let idx = 1
    while filereadable(tempdir.'/'.eval(fname).'.'.ext)
        let idx += 1
    endwhile
"    call Decho('fname = "'.eval(fname).'.'.ext.'"')

    if getcwd() == $VIMRUNTIME
"        call Decho('now we are in $VIMRUNTIME, just out of it...')
        exec 'lcd '.tempdir
"        call Decho('now we are in "'.getcwd().'"')
    endif

    silent exec 'file '.simplify(fnamemodify(tempdir.glob('/').
                \ eval(fname).'.'.ext, ':.'))

    let b:ctk_fname = [expand('%:p'), &ft, 0]
"    call Dret('s:set_filename')
endfunction

function! s:list_compiler(name, idx) " {{{2
    if !s:find_source() | return | endif
    " offer index, just show the speciafied info
    if a:0 != 0 && a:1 != 0
        call s:show_list(b:{s:ci}.list[a:1])

    " didn't offer anything, show the must normal things
    elseif a:name == ''
        if has_key(b:{s:ci}, 'default')
            call s:show_list(b:{s:ci}.default)
        endif
        if !has_key(b:{s:ci}, 'cur_info') " all
            for info in b:{s:ci}.list
                call s:show_list(info)
            endfor
        else " current
            call s:show_list(b:{s:ci}.cur_info)
        endif
    elseif a:name ==? 'all'
        for info in b:{s:ci}.list
            call s:show_list(info)
        endfor
    elseif a:name ==? 'current' && has_key(b:{s:ci}, 'cur_info')
        call s:show_list(b:{s:ci}.cur_info)
    elseif a:name ==? 'default' && has_key(b:{s:ci}, 'default')
        call s:show_list(b:{s:ci}.default)
    else
        call s:show_list(s:get_info(a:name))
    endif
endfunction

function! s:find_source() " {{{2
"    call Dfunc('s:find_source()')
    let cur_winnr = winnr()

    while 1
        if exists(s:ci_name) 
"            call Dret('s:find_source : success')
            return 1 
        endif
        wincmd w
        if winnr() == cur_winnr | break | endif
    endwhile
    call s:echoerr("Can't Find Source Window!")
"    call Dret('s:find_source : fail')
endfunction

function! s:save_source() " {{{2
"    call Dfunc('s:save_source()')

    try 
        silent write 
"        call Dret('s:save_source : success')
        return 1

    catch /E13/ " File exists
        let res = s:question("File Exists, Overwrite?([Y]yes/[N]o/[C]ancel):")

    catch /E45/ " Readonly
        let res = s:question("File Readonly, Still write?([Y]yes/[N]o/[C]ancel):")

    catch
        call s:echoerr('error occur when save source: '.v:exception)
        let res = s:question("Force to write?([Y]yes/[N]o/[C]ancel):")

    endtry

    if res ==? 'y'
        try 
            silent write! 
"            call Dret('s:save_source : success')
            return 1
        catch | call s:echoerr("can't force save source: ".v:exception)
        endtry
    elseif res ==? 'n'
"        call Dret('s:save_source : success')
        return 1
    endif

"    call Dret('s:save_source : fail')
endfunction

function! s:make_cur_info(info) " {{{2
    if expand('%') == '' | return | endif
"    call Dfunc('s:set_cur_info(info = '.a:info.name.')')
    let cur_info = copy(a:info)
    for var in ['cmd', 'run', 'un']
        silent! unlet! cur_info[var.'map']
    endfor
    let b:{s:ci}.cur_info = cur_info

    if exists('b:ctk_fname') && !b:ctk_fname[2]
"        call Decho('filename is an autogenerated name, use defoutput')
        let cur_info.output = g:ctk_defoutput
"    else | call Decho('filename is user-defined')
    endif

    " analyze the modeline to modifie the info
    if &modeline && &mls != 0
        let last = line('$')
        if last <= &mls * 2
            call s:read_modeline(1, last)
        else
            call s:read_modeline(0, &mls)
            call s:read_modeline(last - &mls, last)
        endif
    endif

"    call Dret('s:set_cur_info : '.string(cur_info))
endfunction

function! s:make_cmd(cmd, entry) " {{{2
    if !has_key(b:{s:ci}, 'cur_info') | return | endif
"    call Dfunc('s:make_cmd(cmd = "'.a:cmd.'", entry = "'.a:entry.'"')

    let cmd_get_entry = 's:get_entry_val(a:entry, submatch(1), submatch(0))'
    let cmd_get_default = 's:get_entry_val("", submatch(1), submatch(0))'
    " replace cmdtags and filename
    let cmd = substitute(a:cmd, s:pat_cmdtag, '\='.cmd_get_entry, 'g')
    let cmd = substitute(cmd, s:pat_cmdtag, '\='.cmd_get_default, 'g')
    let cmd = substitute(cmd, s:pat_cmdtag_quote, "\\='\"'.escape(".
                \ cmd_get_entry.", '\\\"').'\"'", 'g')
    let cmd = substitute(cmd, s:pat_cmdtag, '\=escape('.
                \ cmd_get_default.', ''\"'')', 'g')
    let cmd = substitute(cmd, s:pat_filespec_nonescape,
                \ '\=s:expand_fname(submatch(0), cmd[0])', 'g')
    let cmd = substitute(cmd, s:pat_filespec_escape, '', 'g')

    if cmd[0] !~ ':'
"        call Decho('this is a executable cmd')
        let exe = matchstr(cmd, s:pat_shellcmdtitle)
"        call Decho('cmd = '.cmd.', exe = '.exe)

        " on unix, the program must has "./" prefix if it's at current folder
        if has('unix') && glob(exe) != '' && !executable(exe)
                    \ && executable('./'.exe)
            let cmd = './'.(cmd[0] == '!' ? cmd[1:] : cmd)
        endif

        " but ./foobar can't exec on windows :-(
        " so, take of the "./" prefix
        if has('win32') && cmd =~ '^!\=\./'
            let cmd = '!'.(cmd[0] == '!' ? cmd[3:] : cmd[2:])
        endif

        let cmd = cmd[0] != '!' ? '!'.cmd : cmd
    endif

"    call Dret('s:make_cmd : '.cmd)
    return cmd
endfunction

function! s:exec_cmd(cmdarg) " {{{2
    if !has_key(b:{s:ci}, 'cur_info') | return | endif
"    call Dfunc('s:exec_cmd(cmdarg = '.a:cmdarg.')')

    if a:cmdarg[0] == ':'
        " TODO: error when use l:output :-(
        redir => l:output
        exec a:cmdarg
        redir END
        let output = matchstr(output, s:pat_execoutput)
    else
        let output = system(a:cmdarg[0] == '!' ? a:cmdarg[1:] : a:cmdarg)
    endif

"    call Dret('s:exec_cmd : '.output)
    return output
endfunction

function! s:show_list(info) " {{{2
    if empty(a:info) | return | endif

    echohl Title
    echo has_key(a:info, 'name') ?
                \ (has_key(a:info, 'title') ? 
                \ a:info.title."\n\tname         = ".a:info.name."\n"
                \ : a:info.name."\n")
                \ : "Default Values: ".&ft." files"
    echohl NONE

    for key in sort(filter(keys(a:info),
                \ "v:val !~ '".'^\%(title\|name\|unmap\)$'."'"))
        echo printf("\t%-12s = %s", key, a:info[key])
    endfor
endfunction

function! s:read_modeline(begin, end) " {{{2
"    call Dfunc('s:read_modeline(begin = '.a:begin.', end = '.a:end.')')
    let pos = winsaveview()

    call cursor(a:begin, 1)
    while search(s:pat_modeline, '', a:end) != 0
"        call Decho('find a modeline in line '.line('.'))
        let mlist = matchlist(getline('.'), s:pat_modeline)
        if mlist[1] == '' || b:{s:ci}.cur_info.name =~ '^\V'.escape(mlist[1], '\')
            call substitute(mlist[2], s:pat_info_var,
                        \ '\=s:sub_info(b:{s:ci}.cur_info)', 'g')
        endif
    endwhile

    call winrestview(pos)
"    call Dret('s:read_modeline')
endfunction " }}}2

" ============================================================
" clean works {{{1

let &cpo = s:cpo_save
unlet s:cpo_save
"set debug=beep " Decho

" }}}1
" vim: ff=unix ft=vim fdm=marker sw=4 ts=8 et sta nu
